import ctypes 
import tisgrabber as tis
import time

#tisgrabber_x64.dllをインポートする
ic = ctypes.cdll.LoadLibrary("./tisgrabber_x64.dll")
tis.declareFunctions(ic)

#ICImagingControlクラスライブラリを初期化します。
#この関数は、このライブラリの他の関数が呼び出される前に1回だけ呼び出す必要があります。
ic.IC_InitLibrary(0)

#ダイアログ画面を表示
hGrabber = tis.openDevice(ic)

if ic.IC_IsDevValid(hGrabber): 
    # 1920x1080の解像度で表示
    if ic.IC_SetVideoFormat(hGrabber, tis.T("RGB32 (1920x1080)")) == tis.IC_ERROR:
        print("1920x1080の解像度でカラーで表示できません。")
        ic.IC_ReleaseGrabber(hGrabber)
        quit()
    #解像度を指定
    ic.IC_SetFrameRate(hGrabber, ctypes.c_float(30.0))
    #ライブスタート開始　引数：0の時非表示、引数：1の時表示
    ic.IC_StartLive(hGrabber, 1)
 
    # オートフォーカスの有効化
    if ic.IC_SetPropertySwitch(hGrabber, tis.T("Focus"), tis.T("Enable Region of Interest"), 1) == tis.IC_SUCCESS:
        ic.IC_SetPropertyValue(hGrabber, tis.T("Focus"), tis.T("Left"), 100)
        ic.IC_SetPropertyValue(hGrabber, tis.T("Focus"), tis.T("Top"), 100) 
        ic.IC_SetPropertyValue(hGrabber, tis.T("Focus"), tis.T("Right"), 400)
        ic.IC_SetPropertyValue(hGrabber, tis.T("Focus"), tis.T("Bottom"), 400)
    else:
        print("フォーカス制御をサポートしていない機種です。")

    # オートフォーカスのワンプッシュ
    if ic.IC_PropertyOnePush(hGrabber, tis.T("Focus"), tis.T("One Push")) == tis.IC_SUCCESS:
        print("自動フォーカス、スタート")

        onepushrunning = ctypes.c_long()   

        # オートフォーカスが終わるまで待つ
        if ic.IC_GetPropertySwitch(hGrabber, tis.T("Focus"), tis.T("One Push Running"), onepushrunning) == tis.IC_SUCCESS:
            while onepushrunning.value == 1:
                time.sleep(1)
                ic.IC_GetPropertySwitch(hGrabber, tis.T("Focus"), tis.T("One Push Running"), onepushrunning)
        else:
            print("このカメラではワンプッシュの機能はサポートしていません。")

        print("自動フォーカス、終了")
    else:
        print("このカメラではオートフォーカスのワンプッシュをサポートしていません。")

    ic.IC_MsgBox(tis.T("OKボタンで終了します。"), tis.T("Simple Live Video"))
    ic.IC_StopLive(hGrabber)
else:
    ic.IC_MsgBox(tis.T("No device opened"), tis.T("Simple Live Video"))

ic.IC_ReleaseGrabber(hGrabber)
